@@ -11,7 +11,7 @@ void handleXsltError(void *ctx, const char *msg, ...){
   va_list arg_ptr;
   va_start(arg_ptr, msg);
   vsnprintf(string, 1024, msg, arg_ptr);
-  Rcpp::stop("xslt error: %s", string);
+  REprintf("xslt error: %s", string);
 }
 
 void handleError(void* userData, xmlError* error) {
